import matplotlib

MPL_VERSION = matplotlib.__version__

ROOT = "https://aplpy.github.io/aplpy-data/2.x/2018-10-28T17:43:23.106"

# The developer versions of the form 3.2.x+... contain changes that will only
# be included in the 3.3.x release, so we update this here.
if MPL_VERSION[:3] == '3.2' and '+' in MPL_VERSION:
    MPL_VERSION = '3.3'

baseline_dir = ROOT + '/' + MPL_VERSION[:3] + '.x/'



# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
APLpy : Astronomical Plotting Library in Python
"""

# Affiliated packages may add whatever they like to this file, but
# should keep this content at the top.
# ----------------------------------------------------------------------------
from ._astropy_init import *  # noqa
# ----------------------------------------------------------------------------

if not _ASTROPY_SETUP_:  # noqa

    from .core import FITSFigure  # noqa
    from .rgb import make_rgb_image, make_rgb_cube  # noqa

    from .frame import Frame  # noqa
    from .overlays import Scalebar, Beam  # noqa
    from .colorbar import Colorbar  # noqa
    from .grid import Grid  # noqa
    from .ticks import Ticks  # noqa
    from .tick_labels import TickLabels  # noqa
    from .axis_labels import AxisLabels  # noqa
